from django.apps import AppConfig


class DjangoSelect2AutofillConfig(AppConfig):
    default_auto_field = "django.db.models.BigAutoField"
    name = "django_select2_autofill"
    label = "select2_autofill"
